@@ -499,19 +499,6 @@ enum AVPixelFormat {
 
     AV_PIX_FMT_OHCODEC, /// hardware decoding through openharmony
 
-    AV_PIX_FMT_GRAY10MSBBE,   ///<        Y        , 10bpp, lowest bits zero, big-endian
-    AV_PIX_FMT_GRAY10MSBLE,   ///<        Y        , 10bpp, lowest bits zero, little-endian
-    AV_PIX_FMT_GRAY12MSBBE,   ///<        Y        , 12bpp, lowest bits zero, big-endian
-    AV_PIX_FMT_GRAY12MSBLE,   ///<        Y        , 12bpp, lowest bits zero, little-endian
-    AV_PIX_FMT_YUV420P10MSBBE, ///< planar YUV 4:2:0, 15bpp, (1 Cr & Cb sample per 2x2 Y samples), lowest bits zero, big-endian
-    AV_PIX_FMT_YUV420P10MSBLE, ///< planar YUV 4:2:0, 15bpp, (1 Cr & Cb sample per 2x2 Y samples), lowest bits zero, little-endian
-    AV_PIX_FMT_YUV420P12MSBBE, ///< planar YUV 4:2:0, 18bpp, (1 Cr & Cb sample per 2x2 Y samples), lowest bits zero, big-endian
-    AV_PIX_FMT_YUV420P12MSBLE, ///< planar YUV 4:2:0, 18bpp, (1 Cr & Cb sample per 2x2 Y samples), lowest bits zero, little-endian
-    AV_PIX_FMT_YUV422P10MSBBE, ///< planar YUV 4:2:2, 20bpp, (1 Cr & Cb sample per 2x1 Y samples), lowest bits zero, big-endian
-    AV_PIX_FMT_YUV422P10MSBLE, ///< planar YUV 4:2:2, 20bpp, (1 Cr & Cb sample per 2x1 Y samples), lowest bits zero, little-endian
-    AV_PIX_FMT_YUV422P12MSBBE, ///< planar YUV 4:2:2, 24bpp, (1 Cr & Cb sample per 2x1 Y samples), lowest bits zero, big-endian
-    AV_PIX_FMT_YUV422P12MSBLE, ///< planar YUV 4:2:2, 24bpp, (1 Cr & Cb sample per 2x1 Y samples), lowest bits zero, little-endian
-
     AV_PIX_FMT_NB         ///< number of pixel formats, DO NOT USE THIS if you want to link with shared libav* because the number of formats might differ between versions
 };
 
@@ -564,12 +551,6 @@ enum AVPixelFormat {
 #define AV_PIX_FMT_YUV422P16 AV_PIX_FMT_NE(YUV422P16BE, YUV422P16LE)
 #define AV_PIX_FMT_YUV444P16 AV_PIX_FMT_NE(YUV444P16BE, YUV444P16LE)
 
-#define AV_PIX_FMT_GRAY10MSB AV_PIX_FMT_NE(GRAY10MSBBE, GRAY10MSBLE)
-#define AV_PIX_FMT_GRAY12MSB AV_PIX_FMT_NE(GRAY12MSBBE, GRAY12MSBLE)
-#define AV_PIX_FMT_YUV420P10MSB AV_PIX_FMT_NE(YUV420P10MSBBE, YUV420P10MSBLE)
-#define AV_PIX_FMT_YUV420P12MSB AV_PIX_FMT_NE(YUV420P12MSBBE, YUV420P12MSBLE)
-#define AV_PIX_FMT_YUV422P10MSB AV_PIX_FMT_NE(YUV422P10MSBBE, YUV422P10MSBLE)
-#define AV_PIX_FMT_YUV422P12MSB AV_PIX_FMT_NE(YUV422P12MSBBE, YUV422P12MSBLE)
 #define AV_PIX_FMT_YUV444P10MSB AV_PIX_FMT_NE(YUV444P10MSBBE, YUV444P10MSBLE)
 #define AV_PIX_FMT_YUV444P12MSB AV_PIX_FMT_NE(YUV444P12MSBBE, YUV444P12MSBLE)
 
